diff base/Layer.h @ 12:f67ddc287bc3

* Add ability to create empty layers for editing * Add first basic editing capability (adding points to a time instant layer) * Add various keyboard and mouse shortcuts for navigation &c * Add ability to resize a selection by dragging its edges * Add maximum zoom level
author Chris Cannam
date Thu, 26 Jan 2006 16:15:40 +0000
parents ec6886f0e673
children 1fa7cc0d008b
line wrap: on
line diff
--- a/base/Layer.h	Thu Jan 26 11:56:09 2006 +0000
+++ b/base/Layer.h	Thu Jan 26 16:15:40 2006 +0000
@@ -22,6 +22,7 @@
 class Model;
 class QPainter;
 class View;
+class QMouseEvent;
 
 /**
  * The base class for visual representations of the data found in a
@@ -53,6 +54,8 @@
 	return PositionBottom;
     }
 
+    virtual QString getPropertyContainerIconName() const;
+
     virtual QString getPropertyContainerName() const {
 	return objectName();
     }
@@ -92,11 +95,15 @@
 	return frame;
     }
 
     // Paint and edit modes:
     //
     // Layer needs to get actual mouse events, I guess.  Paint mode is
     // probably the easier.
 
+    virtual void drawStart(QMouseEvent *e) { }
+    virtual void drawDrag(QMouseEvent *e) { }
+    virtual void drawEnd(QMouseEvent *e) { }
+
     // Text mode:
     //
     // Label nearest feature.  We need to get the feature coordinates
@@ -92,11 +95,15 @@
     }
 
-    // Paint and edit modes:
+    // Draw and edit modes:
     //
@@ -92,11 +95,15 @@
     //
-    // Layer needs to get actual mouse events, I guess.  Paint mode is
+    // Layer needs to get actual mouse events, I guess.  Draw mode is
     // probably the easier.
 